

VERSION = (0, 9, 1)
"""Application version number tuple."""

VERSION_STR = '.'.join(map(str, VERSION))
"""Application version number string."""


default_app_config = 'siteforms.apps.SiteformsConfig'